@@ -1,5 +1,5 @@
 /*
- * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ GtrBookmark *gtranslator_bookmark_new()
 	
 	bookmark->position=g_list_position(po->messages, po->current);
 
-	bookmark->comment=g_strdup("No comment");
+	bookmark->comment=g_strdup(_("No comment"));
 
 	if(bookmark->position < 0)
 	{
