@@ -1,6 +1,6 @@
 /*
- * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
- *			Gediminas Paulauskas <menesis@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@kabalak.net>
+ *			Gediminas Paulauskas <menesis@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #define GTR_HEADER_STUFF_H 1
 
 #include <gtk/gtkwidget.h>
-#include "messages.h"
+#include "message.h"
 
 /*
  * The header-structure which should hold the header information
