@@ -1,6 +1,6 @@
 /*
- * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
- *			Gediminas Paulauskas <menesis@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@kabalak.net>
+ *			Gediminas Paulauskas <menesis@kabalak.net>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -720,81 +720,6 @@ gchar *gtranslator_utils_get_locale_name(GtrPo *po)
 	}
 }
 
-#ifdef UTF8_CODE
-/*
- * Get the right charset/encoding for the language.
- */
-gchar *gtranslator_utils_get_locale_charset(GtrPo *po)
-{
-	if((!file_opened) || !(po->header->language))
-	{
-		return NULL;
-	}
-	else if(po->header->charset && 
-		(nautilus_strcasecmp(po->header->charset, "utf-8") && 
-		 nautilus_strcasecmp(po->header->charset, "utf8")))
-	{
-		return g_strdup(po->header->charset);
-	}
-	else
-	{
-		gint c;
-
-		for(c=0; languages[c].name!=NULL; c++)
-		{
-			if(!nautilus_strcasecmp(languages[c].name, 
-					po->header->language) ||
-				!nautilus_strcasecmp(_(languages[c].name), 
-					po->header->language))
-			{
-				return g_strdup(languages[c].encoding);
-			}
-			else if(strstr(po->header->language, "/"))
-			{
-				/*
-				 * If no direct language name did match and
-				 *  we have a compound (or not compound :-)) 
-				 *   language name, then we need some voodoo.
-				 */
-				gchar	*partial_charset_name=NULL;
-
-				partial_charset_name=nautilus_str_get_after_prefix(languages[c].name, "/");
-			
-				/*
-				 * Always do grep the after-"/"-language name
-				 *  for our voodoo plays (like mentioned in 
-				 *   b.g.o #69720 for "Norwegian/Nynorsk").
-				 */
-				if(!partial_charset_name)
-				{
-					partial_charset_name=nautilus_str_get_after_prefix(_(languages[c].name), "/");
-				}
-
-				/*
-				 * Now test the language names again for a bit
-				 *  more sanity on "compund" language names.
-				 */
-				if(partial_charset_name && strstr(po->header->language, partial_charset_name))
-				{
-					partial_charset_name++;
-
-					if(nautilus_strcasecmp(partial_charset_name, po->header->language))
-					{
-						return g_strdup(languages[c].encoding);
-					}
-
-					GTR_FREE(partial_charset_name);
-				}
-			}
-		}
-
-		/*
-		 * Again return the fallback default locale value given by the translator.
-		 */
-		return g_strdup(_("iso-8859-1"));
-	}
-}
-#endif
 
 /*
  * Set up the lists to use within the combo boxes.
